@@ -1,18 +1,34 @@
 /*
  * This file is part of LibKGAPI library
  *
- * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
+ * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#pragma once
 
-#include "kgapicontacts_export.h"
+#ifndef LIBKGAPI2_CONTACTSGROUP_H
+#define LIBKGAPI2_CONTACTSGROUP_H
+
 #include "object.h"
 #include "types.h"
+#include "kgapicontacts_export.h"
 
-#include <QDateTime>
+#include <QtCore/QDateTime>
 
 namespace KGAPI2
 {
@@ -21,7 +37,7 @@ namespace KGAPI2
  * @brief Represents a contacts group.
  *
  * Note that this is not the same as vCard contact groups. ContactsGroup is
- * similar to an addressbook - it contains set of full-featured Contacts.
+ * similar to an addressbook - it contains set of full-fetured Contacts.
  *
  * Unlike regular addressbooks however, a single instance of contact can be
  * present in multiple ContactsGroup.
@@ -31,7 +47,8 @@ namespace KGAPI2
  */
 class KGAPICONTACTS_EXPORT ContactsGroup : public KGAPI2::Object
 {
-public:
+  public:
+
     /**
      * @brief Constructor
      */
@@ -45,12 +62,7 @@ public:
     /**
      * @brief Destructor
      */
-    ~ContactsGroup() override;
-
-    /**
-     * @brief Compares the groups
-     */
-    bool operator==(const ContactsGroup &other) const;
+    virtual ~ContactsGroup();
 
     /**
      * @brief Sets group ID
@@ -117,9 +129,12 @@ public:
      */
     bool isSystemGroup() const;
 
-private:
+  private:
     class Private;
-    Private *const d;
+    Private * const d;
+
 };
 
 } // namespace KGAPI2
+
+#endif // LIBKGAPI2_CONTACTSGROUP_H
