@@ -1,17 +1,32 @@
 /*
-    SPDX-FileCopyrightText: 2012 Andrius da Costa Ribas <andriusmao@gmail.com>
+    Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#pragma once
+#ifndef LIBKGAPI2_DRIVE_CHANGE_H
+#define LIBKGAPI2_DRIVE_CHANGE_H
 
-#include "kgapidrive_export.h"
-#include "object.h"
 #include "types.h"
+#include "object.h"
+#include "kgapidrive_export.h"
 
-#include <QString>
-#include <QUrl>
+#include <QtCore/QString>
+#include <QtCore/QUrl>
 
 namespace KGAPI2
 {
@@ -29,17 +44,12 @@ namespace Drive
  * @author Andrius da Costa Ribas <andriusmao@gmail.com>
  * @author Daniel Vrátil <dvratil@redhat.com>
  */
-class KGAPIDRIVE_EXPORT Change : public KGAPI2::Object
+class KGAPIDRIVE_EXPORT Change: public KGAPI2::Object
 {
-public:
+  public:
     explicit Change();
-    explicit Change(const Change &other);
-    ~Change() override;
-    bool operator==(const Change &other) const;
-    bool operator!=(const Change &other) const
-    {
-        return !operator==(other);
-    }
+    explicit Change(const Change& other);
+    virtual ~Change();
 
     /**
      * @brief Returns the id of the change.
@@ -71,9 +81,9 @@ public:
     static ChangePtr fromJSON(const QByteArray &jsonData);
     static ChangesList fromJSONFeed(const QByteArray &jsonData, FeedData &feedData);
 
-private:
+  private:
     class Private;
-    Private *const d;
+    Private * const d;
     friend class Private;
     friend class File;
 };
@@ -81,3 +91,5 @@ private:
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
+
+#endif // LIBKGAPI2_DRIVE_CHANGE_H
