@@ -1,57 +1,78 @@
 /*
  * This file is part of LibKGAPI library
  *
- * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
+ * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+
 #include "fileabstractuploadjob.h"
 #include "account.h"
-#include "debug.h"
+#include "../debug.h"
 #include "driveservice.h"
+#include "file.h"
 #include "utils.h"
 
-#include <QNetworkReply>
 #include <QNetworkRequest>
+#include <QNetworkReply>
 
-#include <QCryptographicHash>
-#include <QFile>
-#include <QFileInfo>
-#include <QMimeDatabase>
 #include <QMimeType>
-#include <QUrlQuery>
+#include <QMimeDatabase>
+#include <QFile>
+#include <QCryptographicHash>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
 class Q_DECL_HIDDEN FileAbstractUploadJob::Private
 {
-public:
+  public:
     Private(FileAbstractUploadJob *parent);
     void processNext();
-    QByteArray buildMultipart(const QString &filePath, const FilePtr &metaData, QString &boundary);
+    QByteArray buildMultipart(const QString &filePath,
+                              const FilePtr &metaData,
+                              QString &boundary);
     QByteArray readFile(const QString &filePath, QString &contentType);
 
     void _k_uploadProgress(qint64 bytesSent, qint64 totalBytes);
 
-    int originalFilesCount = 0;
+    int originalFilesCount;
     QMap<QString, FilePtr> files;
 
     QMap<QString, FilePtr> uploadedFiles;
 
+
+    bool useContentAsIndexableText;
     File::SerializationOptions serializationOptions = File::NoOptions;
 
-private:
+  private:
     FileAbstractUploadJob *const q;
 };
 
-FileAbstractUploadJob::Private::Private(FileAbstractUploadJob *parent)
-    : q(parent)
+FileAbstractUploadJob::Private::Private(FileAbstractUploadJob *parent):
+    originalFilesCount(0),
+    useContentAsIndexableText(false),
+    q(parent)
 {
 }
 
-QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath, QString &contentType)
+QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath,
+                                                    QString &contentType)
 {
     QFile file(filePath);
     if (!file.open(QIODevice::ReadOnly)) {
@@ -59,12 +80,9 @@ QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath, QSt
         return QByteArray();
     }
 
-    if (contentType.isEmpty()) {
-        const QMimeDatabase db;
-        const QMimeType mime = db.mimeTypeForFileNameAndData(filePath, &file);
-        contentType = mime.name();
-        qCDebug(KGAPIDebug) << "Determined content type" << contentType << "for" << filePath;
-    }
+    const QMimeDatabase db;
+    const QMimeType mime = db.mimeTypeForFileNameAndData(filePath, &file);
+    contentType = mime.name();
 
     file.reset();
     QByteArray output = file.readAll();
@@ -74,9 +92,11 @@ QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath, QSt
     return output;
 }
 
-QByteArray FileAbstractUploadJob::Private::buildMultipart(const QString &filePath, const FilePtr &metaData, QString &boundary)
+QByteArray FileAbstractUploadJob::Private::buildMultipart(const QString &filePath,
+                                                          const FilePtr &metaData,
+                                                          QString &boundary)
 {
-    QString fileContentType = metaData->mimeType();
+    QString fileContentType;
     QByteArray fileContent;
 
     fileContent = readFile(filePath, fileContentType);
@@ -84,18 +104,15 @@ QByteArray FileAbstractUploadJob::Private::buildMultipart(const QString &filePat
         return QByteArray();
     }
 
-    qCDebug(KGAPIDebug) << "Setting content type" << fileContentType << "for" << filePath;
-
     // Wannabe implementation of RFC2387, i.e. multipart/related
     QByteArray body;
-    QFileInfo finfo(filePath);
-    const QByteArray md5 = QCryptographicHash::hash(finfo.fileName().toLatin1(), QCryptographicHash::Md5);
+    const QByteArray md5 = QCryptographicHash::hash(filePath.toLatin1(), QCryptographicHash::Md5);
     boundary = QString::fromLatin1(md5.toHex());
 
     body += "--" + boundary.toLatin1() + '\n';
     body += "Content-Type: application/json; charset=UTF-8\n";
     body += '\n';
-    body += File::toJSON(metaData, q->serializationOptions());
+    body += File::toJSON(metaData);
     body += '\n';
     body += '\n';
     body += "--" + boundary.toLatin1() + '\n';
@@ -132,15 +149,16 @@ void FileAbstractUploadJob::Private::processNext()
     }
 
     q->updateUrl(url);
-    QUrlQuery query(url);
+    url.addQueryItem(QStringLiteral("useContentAsIndexableText"), Utils::bool2Str(useContentAsIndexableText));
 
+    QNetworkRequest request;
     QByteArray rawData;
     QString contentType;
 
     // just to be sure
-    query.removeQueryItem(QStringLiteral("uploadType"));
+    url.removeQueryItem(QStringLiteral("uploadType"));
     if (metaData.isNull()) {
-        query.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("media"));
+        url.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("media"));
 
         rawData = readFile(filePath, contentType);
         if (rawData.isEmpty()) {
@@ -149,7 +167,7 @@ void FileAbstractUploadJob::Private::processNext()
         }
 
     } else if (!filePath.startsWith(QLatin1String("?="))) {
-        query.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("multipart"));
+        url.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("multipart"));
 
         QString boundary;
         rawData = buildMultipart(filePath, metaData, boundary);
@@ -164,9 +182,8 @@ void FileAbstractUploadJob::Private::processNext()
         contentType = QStringLiteral("application/json");
     }
 
-    url.setQuery(query);
-
-    QNetworkRequest request(url);
+    request.setUrl(url);
+    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
     request.setHeader(QNetworkRequest::ContentLengthHeader, rawData.length());
     request.setHeader(QNetworkRequest::ContentTypeHeader, contentType);
     request.setAttribute(QNetworkRequest::User, filePath);
@@ -174,66 +191,80 @@ void FileAbstractUploadJob::Private::processNext()
     q->enqueueRequest(request, rawData, contentType);
 }
 
-void FileAbstractUploadJob::Private::_k_uploadProgress(qint64 bytesSent, qint64 totalBytes)
+void FileAbstractUploadJob::Private::_k_uploadProgress(qint64 bytesSent,
+        qint64 totalBytes)
 {
     // Each file consists of 100 units, so if we have two files, one already
     // uploaded and the other one uploaded from 50%, the values are (150, 200)
 
-    int processedParts = (originalFilesCount - files.count() - 1) * 100;
-    int currentFileParts = 100.0 * ((qreal)bytesSent / (qreal)totalBytes);
+    int processedParts = (originalFilesCount - files.count()) * 100;
+    int currentFileParts = 100.0 * ((qreal) bytesSent / (qreal) totalBytes);
 
     q->emitProgress(processedParts + currentFileParts, originalFilesCount * 100);
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const FilePtr &metadata, const AccountPtr &account, QObject *parent)
-    : FileAbstractDataJob(account, parent)
-    , d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const FilePtr &metadata,
+                                             const AccountPtr &account,
+                                             QObject *parent):
+    FileAbstractDataJob(account, parent),
+    d(new Private(this))
 {
     d->files.insert(QStringLiteral("?=0"), metadata);
     d->originalFilesCount = 1;
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const FilesList &metadata, const AccountPtr &account, QObject *parent)
-    : FileAbstractDataJob(account, parent)
-    , d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const FilesList &metadata,
+                                             const AccountPtr &account,
+                                             QObject *parent):
+    FileAbstractDataJob(account, parent),
+    d(new Private(this))
 {
     int i = 0;
-    for (const FilePtr &file : metadata) {
+    Q_FOREACH (const FilePtr &file, metadata) {
         d->files.insert(QStringLiteral("?=%1").arg(i), file);
         ++i;
     }
     d->originalFilesCount = d->files.count();
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath, const AccountPtr &account, QObject *parent)
-    : FileAbstractDataJob(account, parent)
-    , d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath,
+                                             const AccountPtr &account,
+                                             QObject *parent):
+    FileAbstractDataJob(account, parent),
+    d(new Private(this))
 {
     d->files.insert(filePath, FilePtr());
     d->originalFilesCount = 1;
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath, const FilePtr &metaData, const AccountPtr &account, QObject *parent)
-    : FileAbstractDataJob(account, parent)
-    , d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath,
+                                             const FilePtr &metaData,
+                                             const AccountPtr &account,
+                                             QObject *parent):
+    FileAbstractDataJob(account, parent),
+    d(new Private(this))
 {
     d->files.insert(filePath, metaData);
     d->originalFilesCount = 1;
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QStringList &filePaths, const AccountPtr &account, QObject *parent)
-    : FileAbstractDataJob(account, parent)
-    , d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QStringList &filePaths,
+                                             const AccountPtr &account,
+                                             QObject *parent):
+    FileAbstractDataJob(account, parent),
+    d(new Private(this))
 {
-    for (const QString &filePath : filePaths) {
+    Q_FOREACH(const QString & filePath, filePaths) {
         d->files.insert(filePath, FilePtr());
     }
     d->originalFilesCount = d->files.count();
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QMap<QString, FilePtr> &files, const AccountPtr &account, QObject *parent)
-    : FileAbstractDataJob(account, parent)
-    , d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QMap< QString, FilePtr > &files,
+                                             const AccountPtr &account,
+                                             QObject *parent):
+    FileAbstractDataJob(account, parent),
+    d(new Private(this))
 {
     d->files = files;
     d->originalFilesCount = d->files.count();
@@ -244,16 +275,26 @@ FileAbstractUploadJob::~FileAbstractUploadJob()
     delete d;
 }
 
+void FileAbstractUploadJob::setUseContentAsIndexableText(bool useContentAsIndexableText)
+{
+    if (isRunning()) {
+        qCWarning(KGAPIDebug) << "Can't modify useContentAsIndexableText property when job is running";
+        return;
+    }
+
+    d->useContentAsIndexableText = useContentAsIndexableText;
+}
+
+bool FileAbstractUploadJob::useContentAsIndexableText() const
+{
+    return d->useContentAsIndexableText;
+}
+
 void FileAbstractUploadJob::start()
 {
     d->processNext();
 }
 
-QMap<QString, FilePtr> FileAbstractUploadJob::files() const
-{
-    return d->uploadedFiles;
-}
-
 void FileAbstractUploadJob::dispatchRequest(QNetworkAccessManager *accessManager,
                                             const QNetworkRequest &request,
                                             const QByteArray &data,
@@ -263,12 +304,12 @@ void FileAbstractUploadJob::dispatchRequest(QNetworkAccessManager *accessManager
 
     QNetworkReply *reply = dispatch(accessManager, request, data);
 
-    connect(reply, &QNetworkReply::uploadProgress, this, [this](qint64 bytesSent, qint64 totalBytes) {
-        d->_k_uploadProgress(bytesSent, totalBytes);
-    });
+    connect(reply, SIGNAL(uploadProgress(qint64,qint64)),
+            this, SLOT(_k_uploadProgress(qint64,qint64)));
 }
 
-void FileAbstractUploadJob::handleReply(const QNetworkReply *reply, const QByteArray &rawData)
+void FileAbstractUploadJob::handleReply(const QNetworkReply *reply,
+                                        const QByteArray &rawData)
 {
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
@@ -299,4 +340,5 @@ File::SerializationOptions FileAbstractUploadJob::serializationOptions() const
     return d->serializationOptions;
 }
 
+
 #include "moc_fileabstractuploadjob.cpp"
